summaryrefslogtreecommitdiffstats
path: root/kdeui/kjanuswidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
commitf7e71d47719ab6094cf4a9fafffa5ea351973522 (patch)
tree30834aa632d442019e14f88685001d94657d060b /kdeui/kjanuswidget.h
parentb31cfd9a1ee986fe2ae9a693f3afd7f171dd897c (diff)
downloadtdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.tar.gz
tdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.zip
Initial conversion for TQt for Qt4 3.4.0 TP2
This will also compile with TQt for Qt3, and should not cause any problems with dependent modules such as kdebase. If it does then it needs to be fixed! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1214149 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kjanuswidget.h')
-rw-r--r--kdeui/kjanuswidget.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdeui/kjanuswidget.h b/kdeui/kjanuswidget.h
index cc22dc334..5f521612c 100644
--- a/kdeui/kjanuswidget.h
+++ b/kdeui/kjanuswidget.h
@@ -50,12 +50,12 @@ class KGuiItem;
* This class provides KJanusWidget::TreeList, KJanusWidget::IconList,
* KJanusWidget::Tabbed, KJanusWidget::Plain and KJanusWidget::Swallow layouts.
*
* For all modes it is important that you specify the TQWidget::minimumSize()
* on the page, plain widget or the swallowed widget. If you use a QLayout
* on the page, plain widget or the swallowed widget this will be taken care
* of automatically. The size is used when the KJanusWidget determines its
* own minimum size. You get the minimum size by using the
- * minimumSizeHint() or sizeHint() methods.
+ * tqminimumSizeHint() or tqsizeHint() methods.
*
* Pages that have been added in TreeList, IconList or Tabbed mode can be
* removed by simply deleting the page. However, it would be preferable to use
@@ -64,7 +64,7 @@ class KGuiItem;
*
* @author Espen Sand (espen@kde.org)
*/
-class KDEUI_EXPORT KJanusWidget : public QWidget
+class KDEUI_EXPORT KJanusWidget : public TQWidget
{
Q_OBJECT
@@ -77,8 +77,8 @@ class KDEUI_EXPORT KJanusWidget : public QWidget
IconListBox( TQWidget *parent=0, const char *name=0, WFlags f=0 );
void updateMinimumHeight();
void updateWidth();
- void invalidateHeight();
- void invalidateWidth();
+ void tqinvalidateHeight();
+ void tqinvalidateWidth();
void setShowAll( bool showAll );
protected:
@@ -186,7 +186,7 @@ class KDEUI_EXPORT KJanusWidget : public QWidget
*
* @return The minimum size.
*/
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
/**
* Returns the recommended size for the widget in order to be displayed
@@ -194,7 +194,7 @@ class KDEUI_EXPORT KJanusWidget : public QWidget
*
* @return The recommended size.
*/
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/**
* Returns the empty widget that is available in Plain mode.
@@ -50,12 +50,12 @@ class KGuiItem;
* KJanusWidget::Tabbed, KJanusWidget::Plain and KJanusWidget::Swallow layouts.
*
- * For all modes it is important that you specify the TQWidget::minimumSize()
+ * For all modes it is important that you specify the TQWidget::tqminimumSize()
* on the page, plain widget or the swallowed widget. If you use a QLayout
* on the page, plain widget or the swallowed widget this will be taken care